wallaby v0.9.0 Wallaby
A concurrent feature testing library.
Configuration
Wallaby supports the following options:
:pool_size- Maximum amount of phantoms to run. The default is:erlang.system_info(:schedulers_online) * 2.:screenshot_dir- The directory to store screenshots.:screenshot_on_failure- if Wallaby should take screenshots on test failures (defaults tofalse).:max_wait_time- The amount of time that Wallaby should wait to find an element on the page. (defaults to3_000):js_errors- if Wallaby should re-throw javascript errors in elixir (defaults to true).
Summary
Functions
Callback implementation for c:Application.start/2